<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../../src/maemo5/aboutdialog.cpp" line="32"/>
        <source>A user-friendly internet radio player.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/aboutdialog.cpp" line="34"/>
        <source>Donate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/aboutdialog.cpp" line="35"/>
        <source>Report bug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/aboutdialog.cpp" line="38"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddStationDialog</name>
    <message>
        <location filename="../../src/maemo5/addstationdialog.cpp" line="38"/>
        <location filename="../../src/maemo5/addstationdialog.cpp" line="85"/>
        <source>Favourite?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/addstationdialog.cpp" line="43"/>
        <source>Add station</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/addstationdialog.cpp" line="48"/>
        <location filename="../../src/maemo5/addstationdialog.cpp" line="95"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/addstationdialog.cpp" line="50"/>
        <location filename="../../src/maemo5/addstationdialog.cpp" line="97"/>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/addstationdialog.cpp" line="52"/>
        <location filename="../../src/maemo5/addstationdialog.cpp" line="99"/>
        <source>Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/addstationdialog.cpp" line="54"/>
        <location filename="../../src/maemo5/addstationdialog.cpp" line="101"/>
        <source>Country</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/addstationdialog.cpp" line="56"/>
        <location filename="../../src/maemo5/addstationdialog.cpp" line="103"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/addstationdialog.cpp" line="58"/>
        <location filename="../../src/maemo5/addstationdialog.cpp" line="105"/>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/addstationdialog.cpp" line="90"/>
        <source>Edit station</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BrowseListDelegate</name>
    <message>
        <location filename="../../src/maemo5/browselistdelegate.cpp" line="52"/>
        <source>%1 stations</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BrowseListWindow</name>
    <message>
        <location filename="../../src/maemo5/browselistwindow.cpp" line="76"/>
        <source>Stations by genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/browselistwindow.cpp" line="77"/>
        <source>No genres found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/browselistwindow.cpp" line="82"/>
        <source>Stations by country</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/browselistwindow.cpp" line="83"/>
        <source>No countries found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/browselistwindow.cpp" line="88"/>
        <source>Stations by language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/browselistwindow.cpp" line="89"/>
        <source>No languages found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Database</name>
    <message>
        <location filename="../../src/base/database.cpp" line="104"/>
        <source>New station</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/database.cpp" line="104"/>
        <source>added</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/database.cpp" line="110"/>
        <location filename="../../src/base/database.cpp" line="115"/>
        <source>Cannot add new station</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/database.cpp" line="177"/>
        <location filename="../../src/base/database.cpp" line="236"/>
        <source>Station updated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/database.cpp" line="184"/>
        <location filename="../../src/base/database.cpp" line="243"/>
        <source>Cannot update station</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/database.cpp" line="281"/>
        <source>Station deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/database.cpp" line="286"/>
        <location filename="../../src/base/database.cpp" line="291"/>
        <source>Cannot delete station</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HomescreenModel</name>
    <message>
        <location filename="../../src/base/homescreenmodel.cpp" line="22"/>
        <source>Stations by genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/homescreenmodel.cpp" line="23"/>
        <source>Stations by country</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/homescreenmodel.cpp" line="24"/>
        <source>Stations by language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/homescreenmodel.cpp" line="25"/>
        <source>Recently played stations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/homescreenmodel.cpp" line="26"/>
        <source>Favourite stations</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LanguageModel</name>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="79"/>
        <source>Afar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="80"/>
        <source>Abkhazian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="81"/>
        <source>Afrikaans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="82"/>
        <source>Akan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="83"/>
        <source>Albanian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="84"/>
        <source>Amharic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="85"/>
        <source>Arabic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="86"/>
        <source>Aragonese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="87"/>
        <source>Armenian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="88"/>
        <source>Assamese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="89"/>
        <source>Avaric</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="90"/>
        <source>Avestan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="91"/>
        <source>Aymara</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="92"/>
        <source>Azerbaijani</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="93"/>
        <source>Bashkir</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="94"/>
        <source>Bambara</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="95"/>
        <source>Basque</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="96"/>
        <source>Belarusian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="97"/>
        <source>Bengali</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="98"/>
        <source>Bihari languages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="99"/>
        <source>Bislama</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="100"/>
        <source>Bosnian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="101"/>
        <source>Breton</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="102"/>
        <source>Bulgarian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="103"/>
        <source>Burmese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="104"/>
        <source>Catalan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="105"/>
        <source>Central Khmer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="106"/>
        <source>Chamorro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="107"/>
        <source>Chechen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="108"/>
        <source>Chichewa</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="109"/>
        <source>Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="110"/>
        <source>Church Slavic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="111"/>
        <source>Chuvash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="112"/>
        <source>Cornish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="113"/>
        <source>Corsican</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="114"/>
        <source>Cree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="115"/>
        <source>Croatian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="116"/>
        <source>Czech</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="117"/>
        <source>Danish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="118"/>
        <source>Divehi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="119"/>
        <source>Dutch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="120"/>
        <source>Dzongkha</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="121"/>
        <source>English</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="122"/>
        <source>Esperanto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="123"/>
        <source>Estonian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="124"/>
        <source>Ewe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="125"/>
        <source>Faroese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="126"/>
        <source>Fijian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="127"/>
        <source>Finnish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="128"/>
        <source>French</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="129"/>
        <source>Fulah</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="130"/>
        <source>Gaelic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="131"/>
        <source>Galician</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="132"/>
        <source>Ganda</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="133"/>
        <source>Georgian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="134"/>
        <source>German</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="135"/>
        <source>Greek</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="136"/>
        <source>Guarani</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="137"/>
        <source>Gujarati</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="138"/>
        <source>Haitian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="139"/>
        <source>Hausa</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="140"/>
        <source>Hebrew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="141"/>
        <source>Herero</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="142"/>
        <source>Hindi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="143"/>
        <source>Hiri Motu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="144"/>
        <source>Hungarian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="145"/>
        <source>Icelandic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="146"/>
        <source>Ido</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="147"/>
        <source>Igbo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="148"/>
        <source>Indonesian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="149"/>
        <source>Inuktitut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="150"/>
        <source>Interlingua</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="151"/>
        <source>Interlingue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="152"/>
        <source>Inupiaq</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="153"/>
        <source>Irish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="154"/>
        <source>Italian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="155"/>
        <source>Japanese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="156"/>
        <source>Javanese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="157"/>
        <source>Kalaallisut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="158"/>
        <source>Kannada</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="159"/>
        <source>Kanuri</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="160"/>
        <source>Kashmiri</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="161"/>
        <source>Kazakh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="162"/>
        <source>Kikuyu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="163"/>
        <source>Kinyarwanda</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="164"/>
        <source>Kirghiz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="165"/>
        <source>Komi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="166"/>
        <source>Kongo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="167"/>
        <source>Korean</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="168"/>
        <source>Kuanyama</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="169"/>
        <source>Kurdish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="170"/>
        <source>Lao</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="171"/>
        <source>Latin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="172"/>
        <source>Latvian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="173"/>
        <source>Limburgan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="174"/>
        <source>Lingala</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="175"/>
        <source>Lithuanian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="176"/>
        <source>Luxembourgish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="177"/>
        <source>Luba-Katanga</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="178"/>
        <source>Macedonian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="179"/>
        <source>Malagasy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="180"/>
        <source>Malay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="181"/>
        <source>Malayalam</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="182"/>
        <source>Maltese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="183"/>
        <source>Manx</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="184"/>
        <source>Maori</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="185"/>
        <source>Marathi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="186"/>
        <source>Marshallese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="187"/>
        <source>Mongolian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="188"/>
        <source>Nauru</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="189"/>
        <source>Navajo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="190"/>
        <source>Ndebele, North</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="191"/>
        <source>Ndebele, South</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="192"/>
        <source>Ndonga</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="193"/>
        <source>Nepali</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="194"/>
        <source>Northern Sami</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="195"/>
        <source>Norwegian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="196"/>
        <source>Norwegian BokmÃ¥l</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="197"/>
        <source>Norwegian Nynorsk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="198"/>
        <source>Occitan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="199"/>
        <source>Ojibwa</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="200"/>
        <source>Oriya</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="201"/>
        <source>Oromo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="202"/>
        <source>Ossetian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="203"/>
        <source>Pali</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="204"/>
        <source>Persian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="205"/>
        <source>Polish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="206"/>
        <source>Portuguese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="207"/>
        <source>Punjabi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="208"/>
        <source>Pushto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="209"/>
        <source>Quechua</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="210"/>
        <source>Romansh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="211"/>
        <source>Romanian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="212"/>
        <source>Rundi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="213"/>
        <source>Russian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="214"/>
        <source>Samoan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="215"/>
        <source>Sango</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="216"/>
        <source>Sanskrit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="217"/>
        <source>Sardinian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="218"/>
        <source>Serbian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="219"/>
        <source>Shona</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="220"/>
        <source>Sindhi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="221"/>
        <source>Sinhala</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="222"/>
        <source>Sichuan Yi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="223"/>
        <source>Slovak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="224"/>
        <source>Slovenian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="225"/>
        <source>Somali</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="226"/>
        <source>Sotho, Southern</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="227"/>
        <source>Spanish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="228"/>
        <source>Sundanese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="229"/>
        <source>Swahili</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="230"/>
        <source>Swati</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="231"/>
        <source>Swedish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="232"/>
        <source>Tagalog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="233"/>
        <source>Tahitian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="234"/>
        <source>Tajik</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="235"/>
        <source>Tamil</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="236"/>
        <source>Tatar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="237"/>
        <source>Telugu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="238"/>
        <source>Thai</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="239"/>
        <source>Tibetan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="240"/>
        <source>Tigrinya</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="241"/>
        <source>Tonga</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="242"/>
        <source>Tsonga</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="243"/>
        <source>Tswana</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="244"/>
        <source>Turkish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="245"/>
        <source>Turkmen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="246"/>
        <source>Twi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="247"/>
        <source>Uighur</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="248"/>
        <source>Ukrainian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="249"/>
        <source>Urdu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="250"/>
        <source>Uzbek</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="251"/>
        <source>Venda</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="252"/>
        <source>Vietnamese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="253"/>
        <source>VolapÃ¼k</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="254"/>
        <source>Walloon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="255"/>
        <source>Welsh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="256"/>
        <source>Western Frisian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="257"/>
        <source>Wolof</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="258"/>
        <source>Xhosa</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="259"/>
        <source>Yiddish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="260"/>
        <source>Yoruba</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="261"/>
        <source>Zhuang</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="262"/>
        <source>Zulu</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../src/maemo5/mainwindow.cpp" line="45"/>
        <source>cuteRadio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/mainwindow.cpp" line="47"/>
        <source>Add station</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/mainwindow.cpp" line="48"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/mainwindow.cpp" line="49"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/mainwindow.cpp" line="52"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaPlayer</name>
    <message>
        <location filename="../../src/mediaplayer/phonon/mediaplayer.cpp" line="143"/>
        <source>Buffering media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mediaplayer/phonon/mediaplayer.cpp" line="148"/>
        <source>Playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mediaplayer/phonon/mediaplayer.cpp" line="150"/>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mediaplayer/phonon/mediaplayer.cpp" line="152"/>
        <source>Stopped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mediaplayer/phonon/mediaplayer.cpp" line="154"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mediaplayer/phonon/mediaplayer.cpp" line="156"/>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkProxyTypeModel</name>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="305"/>
        <source>caching</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NowPlayingWindow</name>
    <message>
        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="65"/>
        <source>Now playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="169"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="170"/>
        <source>Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="170"/>
        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="171"/>
        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="173"/>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="171"/>
        <source>Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="172"/>
        <source>Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="173"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="178"/>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScreenOrientationModel</name>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="68"/>
        <source>Automatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="69"/>
        <source>Portrait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/selectionmodels.cpp" line="70"/>
        <source>Landscape</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../../src/maemo5/settingsdialog.cpp" line="30"/>
        <source>Screen orientation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/settingsdialog.cpp" line="31"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/settingsdialog.cpp" line="37"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/settingsdialog.cpp" line="44"/>
        <source>Sleep timer duration (mins)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Station</name>
    <message>
        <location filename="../../src/base/station.cpp" line="195"/>
        <source>Never</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/station.cpp" line="202"/>
        <source>Today</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/station.cpp" line="205"/>
        <source>Yesterday</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StationInfoWindow</name>
    <message>
        <location filename="../../src/maemo5/stationinfowindow.cpp" line="38"/>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationinfowindow.cpp" line="39"/>
        <location filename="../../src/maemo5/stationinfowindow.cpp" line="150"/>
        <source>Delete from favourites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationinfowindow.cpp" line="39"/>
        <location filename="../../src/maemo5/stationinfowindow.cpp" line="150"/>
        <source>Add to favourites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationinfowindow.cpp" line="40"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationinfowindow.cpp" line="41"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationinfowindow.cpp" line="58"/>
        <source>Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationinfowindow.cpp" line="115"/>
        <source>Delete station?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationinfowindow.cpp" line="115"/>
        <source>Do you wish to delete the station &apos;%1&apos; from the database?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationinfowindow.cpp" line="126"/>
        <source>No description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationinfowindow.cpp" line="130"/>
        <source>Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationinfowindow.cpp" line="130"/>
        <location filename="../../src/maemo5/stationinfowindow.cpp" line="134"/>
        <location filename="../../src/maemo5/stationinfowindow.cpp" line="138"/>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationinfowindow.cpp" line="134"/>
        <source>Country</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationinfowindow.cpp" line="138"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationinfowindow.cpp" line="142"/>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationinfowindow.cpp" line="146"/>
        <source>Last played</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StationListWindow</name>
    <message>
        <location filename="../../src/maemo5/stationlistwindow.cpp" line="42"/>
        <source>View info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationlistwindow.cpp" line="43"/>
        <location filename="../../src/maemo5/stationlistwindow.cpp" line="140"/>
        <source>Add to favourites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationlistwindow.cpp" line="44"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationlistwindow.cpp" line="45"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationlistwindow.cpp" line="46"/>
        <source>No stations found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationlistwindow.cpp" line="48"/>
        <source>Stations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationlistwindow.cpp" line="87"/>
        <source>Search (&apos;%1&apos;)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationlistwindow.cpp" line="92"/>
        <source>Recently played stations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationlistwindow.cpp" line="97"/>
        <source>Favourite stations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationlistwindow.cpp" line="140"/>
        <source>Delete from favourites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationlistwindow.cpp" line="166"/>
        <source>Delete station?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/maemo5/stationlistwindow.cpp" line="166"/>
        <source>Do you wish to delete the station &apos;%1&apos; from the database?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StreamExtractor</name>
    <message>
        <location filename="../../src/base/streamextractor.cpp" line="68"/>
        <source>Network error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/streamextractor.cpp" line="95"/>
        <source>Cannot find stream url</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../../src/base/utils.cpp" line="106"/>
        <source>Bad request</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/utils.cpp" line="108"/>
        <source>Request is unauthorised</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/utils.cpp" line="110"/>
        <source>Request is forbidden</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/utils.cpp" line="112"/>
        <source>Requested resource is unavailable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/utils.cpp" line="114"/>
        <source>Requested resource is not accessible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/utils.cpp" line="116"/>
        <source>Request cannot be processed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/utils.cpp" line="118"/>
        <source>Request limit has been reached. Please try again later</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/utils.cpp" line="120"/>
        <source>Internal server error. Please try again later</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/utils.cpp" line="122"/>
        <source>Service unavailable. Please try again later</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/utils.cpp" line="124"/>
        <source>Request timed out. Please try again later</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/base/utils.cpp" line="126"/>
        <source>Unknown error. Please try again later</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
